@@ -87,6 +87,7 @@ impl Aviffy {
         let alpha_image_id = 2;
         let high_bitdepth = depth_bits >= 10;
         let twelve_bit = depth_bits >= 12;
+        const ESSENTIAL_BIT: u8 = 0x80;
 
         image_items.push(InfeBox {
             id: color_image_id,
@@ -96,8 +97,8 @@ impl Aviffy {
         let ispe_prop = ipco.push(IpcoProp::Ispe(IspeBox { width, height }));
         // This is redundant, but Chrome wants it, and checks that it matches :(
         let av1c_prop = ipco.push(IpcoProp::Av1C(Av1CBox {
-            seq_profile: false,
-            seq_level_idx_0: 0,
+            seq_profile: if twelve_bit { 2 } else { 1 },
+            seq_level_idx_0: 31,
             seq_tier_0: false,
             high_bitdepth,
             twelve_bit,
@@ -113,7 +114,7 @@ impl Aviffy {
         }));
         ipma_entries.push(IpmaEntry {
             item_id: color_image_id,
-            prop_ids: [ispe_prop, av1c_prop, pixi_3].iter().copied().collect(),
+            prop_ids: [ispe_prop, av1c_prop | ESSENTIAL_BIT, pixi_3].iter().copied().collect(),
         });
 
         if let Some(alpha_data) = alpha_av1_data {
@@ -123,14 +124,14 @@ impl Aviffy {
                 name: "",
             });
             let av1c_prop = ipco.push(boxes::IpcoProp::Av1C(Av1CBox {
-                seq_profile: false,
-                seq_level_idx_0: 0,
+                seq_profile: if twelve_bit { 2 } else { 0 },
+                seq_level_idx_0: 31,
                 seq_tier_0: false,
                 high_bitdepth,
                 twelve_bit,
                 monochrome: true,
-                chroma_subsampling_x: false,
-                chroma_subsampling_y: false,
+                chroma_subsampling_x: true,
+                chroma_subsampling_y: true,
                 chroma_sample_position: 0,
             }));
             // So pointless
@@ -161,7 +162,7 @@ impl Aviffy {
             }
             ipma_entries.push(IpmaEntry {
                 item_id: alpha_image_id,
-                prop_ids: [ispe_prop, av1c_prop, auxc_prop, pixi_1].iter().copied().collect(),
+                prop_ids: [ispe_prop, av1c_prop | ESSENTIAL_BIT, auxc_prop, pixi_1].iter().copied().collect(),
             });
 
             // Use interleaved color and alpha, with alpha first.
